using System;
using System.IO;
using System.Text;
using NUnit.Framework;
using VisionTech.HtmlTidy;

namespace TestHarness {
	[TestFixture]
	public class TestFuncs {
		private Document m_doc;
		const string T1 = "<html>\r\n<head>\r\n<title></title>\r\n</head>\r\n<body>\r\n</body>\r\n</html>\r\n";
		const string T2 = "<title>Foo</title><p>Foo!";

		[SetUp]
		public void Init() {
			m_doc = new Document();
		}

		[TearDown]
		public void Term() {
			m_doc.Dispose();
			m_doc = null;
		}

		[Test]
		public void SimpleString() {
			m_doc.ParseString(T1);
			string c;
			m_doc.SaveString(out c);
			Assertion.AssertEquals(T1,c);
			Console.WriteLine(m_doc.Errors);
		}

		[Test]
		public void Fragment() {
			m_doc.ParseString(T2);
			m_doc.CleanAndRepair();
			m_doc.RunDiagnostics();
			m_doc.SetOption(OptionId.ForceOutput,true);

			string c;
			m_doc.SaveString(out c);
			Console.Error.WriteLine(c);
			Console.WriteLine(m_doc.Errors);
		}

		[Test]
		public void StreamInput() {
			using(MemoryStream stm = new MemoryStream(Encoding.ASCII.GetBytes(T1))) {
				m_doc.ParseStream(stm);
			}
			string c;
			m_doc.SaveString(out c);
			Assertion.AssertEquals(T1,c);
		}

		[Test]
		public void StreamOutput() {
			m_doc.ParseString(T1);
			MemoryStream stm = new MemoryStream();
			m_doc.SaveStream(stm);
			string c = Encoding.ASCII.GetString(stm.ToArray());
			Assertion.AssertEquals(T1,c);
		}
	}
}