/////////////////////////////////////////////////////////////////////////////
//
// Html Tidy .NET Binding
// (C) Copyright 2003 VisionTech Limited. All rights reserved.
// http://www.visiontech.ltd.uk/
// bateman@acm.org
//
// VisionTech Limited makes no warranties, either express or implied,
// with respect to this source code and any accompanying materials.
//
// In no event shall VisionTech Limited or its suppliers be liable for
// any damages whatsoever (including, without limitation, damages for
// loss of business profits, business interruption, loss of business
// information, or other percuniary loss) arising out of the use or
// inability to use this software.
//
// This source code may be used for any purpose, including commercial
// applications, and may be modified or redistributed subject to the
// following conditions:
//
// a) This notice may not be removed or changed in any source distribution.
//
// b) Altered source versions must include a note to that effect,
//    and must not be misrepresented as the original.
//
// c) The origin of this software may not be misrepresented - you may
//    not claim to have written the original version. If you use this
//    source in a product, an acknowledgement in the documentation
//    would be appreciated, but is not required.
//
/////////////////////////////////////////////////////////////////////////////

// Handle managed version of enums

/** Option IDs Used to get/set option values.
*/
public __value enum OptionId
{
  UnknownOption,   /**< Unknown option! */
  IndentSpaces,    /**< Indentation n spaces */
  WrapLen,         /**< Wrap margin */
  TabSize,         /**< Expand tabs to n spaces */

  CharEncoding,    /**< In/out character encoding */
  InCharEncoding,  /**< Input character encoding (if different) */
  OutCharEncoding, /**< Output character encoding (if different) */    
  Newline,         /**< Output line ending (default to platform) */

  DoctypeMode,     /**< See doctype property */
  Doctype,         /**< User specified doctype */

  DuplicateAttrs,  /**< Keep first or last duplicate attribute */
  AltText,         /**< Default text for alt attribute */
  SlideStyle,      /**< Style sheet for slides: not used for anything yet */
  ErrFile,         /**< File name to write errors to */
  OutFile,         /**< File name to write markup to */
  WriteBack,       /**< If true then output tidied markup */
  ShowMarkup,      /**< If false, normal output is suppressed */
  ShowWarnings,    /**< However errors are always shown */
  Quiet,           /**< No 'Parsing X', guessed DTD or summary */
  IndentContent,   /**< Indent content of appropriate tags */
                       /**< "auto" does text/block level content indentation */
  HideEndTags,     /**< Suppress optional end tags */
  XmlTags,         /**< Treat input as XML */
  XmlOut,          /**< Create output as XML */
  XhtmlOut,        /**< Output extensible HTML */
  HtmlOut,         /**< Output plain HTML, even for XHTML input.
                           Yes means set explicitly. */
  XmlDecl,         /**< Add <?xml?> for XML docs */
  UpperCaseTags,   /**< Output tags in upper not lower case */
  UpperCaseAttrs,  /**< Output attributes in upper not lower case */
  MakeBare,        /**< Make bare HTML: remove Microsoft cruft */
  MakeClean,       /**< Replace presentational clutter by style rules */
  LogicalEmphasis, /**< Replace i by em and b by strong */
  DropPropAttrs,   /**< Discard proprietary attributes */
  DropFontTags,    /**< Discard presentation tags */
  DropEmptyParas,  /**< Discard empty p elements */
  FixComments,     /**< Fix comments with adjacent hyphens */
  BreakBeforeBR,   /**< Output newline before <br> or not? */
  BurstSlides,     /**< Create slides on each h2 element */
  NumEntities,     /**< Use numeric entities */
  QuoteMarks,      /**< Output " marks as &quot; */
  QuoteNbsp,       /**< Output non-breaking space as entity */
  QuoteAmpersand,  /**< Output naked ampersand as &amp; */
  WrapAttVals,     /**< Wrap within attribute values */
  WrapScriptlets,  /**< Wrap within JavaScript string literals */
  WrapSection,     /**< Wrap within <![ ... ]> section tags */
  WrapAsp,         /**< Wrap within ASP pseudo elements */
  WrapJste,        /**< Wrap within JSTE pseudo elements */
  WrapPhp,         /**< Wrap within PHP pseudo elements */
  FixBackslash,    /**< Fix URLs by replacing \ with / */
  IndentAttributes,/**< Newline+indent before each attribute */
  XmlPIs,          /**< If set to yes PIs must end with ?> */
  XmlSpace,        /**< If set to yes adds xml:space attr as needed */
  EncloseBodyText, /**< If yes text at body is wrapped in P's */
  EncloseBlockText,/**< If yes text in blocks is wrapped in P's */
  KeepFileTimes,   /**< If yes last modied time is preserved */
  Word2000,        /**< Draconian cleaning for Word2000 */
  Mark,            /**< Add meta element indicating tidied doc */
  Emacs,           /**< If true format error output for GNU Emacs */
  EmacsFile,       /**< Name of current Emacs file */
  LiteralAttribs,  /**< If true attributes may use newlines */
  BodyOnly,        /**< Output BODY content only */
  FixUri,          /**< Applies URI encoding if necessary */
  LowerLiterals,   /**< Folds known attribute values to lower case */
  HideComments,    /**< Hides all (real) comments in output */
  IndentCdata,     /**< Indent <!CDATA[ ... ]]> section */
  ForceOutput,     /**< Output document even if errors were found */
  ShowErrors,      /**< Number of errors to put out */
  AsciiChars,      /**< Convert quotes and dashes to nearest ASCII char */
  JoinClasses,     /**< Join multiple class attributes */
  JoinStyles,      /**< Join multiple style attributes */
  EscapeCdata,     /**< Replace <![CDATA[]]> sections with escaped text */

#if SUPPORT_ASIAN_ENCODINGS
  Language,        /**< Language property: not used for anything yet */
  NCR,             /**< Allow numeric character references */
#endif
#if SUPPORT_UTF16_ENCODINGS
  OutputBOM,      /**< Output a Byte Order Mark (BOM) for UTF-16 encodings */
                      /**< auto: if input stream has BOM, we output a BOM */
#endif

  ReplaceColor,    /**< Replace hex color attribute values with names */
  CSSPrefix,       /**< CSS class naming for -clean option */

  InlineTags,      /**< Declared inline tags */
  BlockTags,       /**< Declared block tags */
  EmptyTags,       /**< Declared empty tags */
  PreTags,         /**< Declared pre tags */

  AccessibilityCheckLevel, /**< Accessibility check level 
                                   0 (old style), or 1, 2, 3 */

  VertSpace,       /**< degree to which markup is spread out vertically */
#if SUPPORT_ASIAN_ENCODINGS
  PunctWrap,       /**< consider punctuation and breaking spaces for wrapping */
#endif
  N_TIDY_OPTIONS       /**< Must be last */
};

/** AutoBool values used by ParseBool, ParseTriState, ParseIndent, ParseBOM
*/
public __value enum AutoBool
{
   No,     /**< maps to 'no' */
   Yes,    /**< maps to 'yes' */
   Auto	   /**< Automatic */
};

/** TidyNewline option values to control output line endings.
*/
public __value enum LineEnding
{
    LF,         /**< Use Unix style: LF */
    CRLF,       /**< Use DOS/Windows style: CR+LF */
    CR          /**< Use Macintosh style: CR */
};


/** Mode controlling treatment of doctype
*/
public __value enum DoctypeModes
{
    DoctypeOmit,    /**< Omit DOCTYPE altogether */
    DoctypeAuto,    /**< Keep DOCTYPE in input.  Set version to content */
    DoctypeStrict,  /**< Convert document to HTML 4 strict content model */
    DoctypeLoose,   /**< Convert document to HTML 4 transitional
                             content model */
    DoctypeUser     /**< Set DOCTYPE FPI explicitly */
};

/** Mode controlling treatment of duplicate Attributes
*/
public __value enum DupAttrModes
{
    KeepFirst,
    KeepLast
};


#if 0 // node code not yet supported


/* Document tree traversal functions
*/

/** Node types
*/
public __value enum NodeType
{
  Root,        /**< Root */
  DocType,     /**< DOCTYPE */
  Comment,     /**< Comment */
  ProcIns,     /**< Processing Instruction */
  Text,        /**< Text */
  Start,       /**< Start Tag */
  End,         /**< End Tag */
  StartEnd,    /**< Start/End (empty) Tag */
  CDATA,       /**< Unparsed Text */
  Section,     /**< XML Section */
  Asp,         /**< ASP Source */
  Jste,        /**< JSTE Source */
  Php,         /**< PHP Source */
  XmlDecl      /**< XML Declaration */
};


/** Known HTML element types
*/
public __value enum TagId
{
  UNKNOWN,  /**< Unknown tag! */
  A,        /**< A */
  ABBR,     /**< ABBR */
  ACRONYM,  /**< ACRONYM */
  ADDRESS,  /**< ADDRESS */
  ALIGN,    /**< ALIGN */
  APPLET,   /**< APPLET */
  AREA,     /**< AREA */
  B,        /**< B */
  BASE,     /**< BASE */
  BASEFONT, /**< BASEFONT */
  BDO,      /**< BDO */
  BGSOUND,  /**< BGSOUND */
  BIG,      /**< BIG */
  BLINK,    /**< BLINK */
  BLOCKQUOTE,   /**< BLOCKQUOTE */
  BODY,     /**< BODY */
  BR,       /**< BR */
  BUTTON,   /**< BUTTON */
  CAPTION,  /**< CAPTION */
  CENTER,   /**< CENTER */
  CITE,     /**< CITE */
  CODE,     /**< CODE */
  COL,      /**< COL */
  COLGROUP, /**< COLGROUP */
  COMMENT,  /**< COMMENT */
  DD,       /**< DD */
  DEL,      /**< DEL */
  DFN,      /**< DFN */
  DIR,      /**< DIR */
  DIV,      /**< DIF */
  DL,       /**< DL */
  DT,       /**< DT */
  EM,       /**< EM */
  EMBED,    /**< EMBED */
  FIELDSET, /**< FIELDSET */
  FONT,     /**< FONT */
  FORM,     /**< FORM */
  FRAME,    /**< FRAME */
  FRAMESET, /**< FRAMESET */
  H1,       /**< H1 */
  H2,       /**< H2 */
  H3,       /**< H3 */
  H4,       /**< H4 */
  H5,       /**< H5 */
  H6,       /**< H6 */
  HEAD,     /**< HEAD */
  HR,       /**< HR */
  HTML,     /**< HTML */
  I,        /**< I */
  IFRAME,   /**< IFRAME */
  ILAYER,   /**< ILAYER */
  IMG,      /**< IMG */
  INPUT,    /**< INPUT */
  INS,      /**< INS */
  ISINDEX,  /**< ISINDEX */
  KBD,      /**< KBD */
  KEYGEN,   /**< KEYGEN */
  LABEL,    /**< LABEL */
  LAYER,    /**< LAYER */
  LEGEND,   /**< LEGEND */
  LI,       /**< LI */
  LINK,     /**< LINK */
  LISTING,  /**< LISTING */
  MAP,      /**< MAP */
  MARQUEE,  /**< MARQUEE */
  MENU,     /**< MENU */
  META,     /**< META */
  MULTICOL, /**< MULTICOL */
  NOBR,     /**< NOBR */
  NOEMBED,  /**< NOEMBED */
  NOFRAMES, /**< NOFRAMES */
  NOLAYER,  /**< NOLAYER */
  NOSAVE,   /**< NOSAVE */
  NOSCRIPT, /**< NOSCRIPT */
  OBJECT,   /**< OBJECT */
  OL,       /**< OL */
  OPTGROUP, /**< OPTGROUP */
  OPTION,   /**< OPTION */
  P,        /**< P */
  PARAM,    /**< PARAM */
  PLAINTEXT,    /**< PLAINTEXT */
  PRE,      /**< PRE */
  Q,        /**< Q */
  RB,       /**< RB */
  RBC,      /**< RBC */
  RP,       /**< RP */
  RT,       /**< RT */
  RTC,      /**< RTC */
  RUBY,     /**< RUBY */
  S,        /**< S */
  SAMP,     /**< SAMP */
  SCRIPT,   /**< SCRIPT */
  SELECT,   /**< SELECT */
  SERVER,   /**< SERVER */
  SERVLET,  /**< SERVLET */
  SMALL,    /**< SMALL */
  SPACER,   /**< SPACER */
  SPAN,     /**< SPAN */
  STRIKE,   /**< STRIKE */
  STRONG,   /**< STRONG */
  STYLE,    /**< STYLE */
  SUB,      /**< SUB */
  SUP,      /**< SUP */
  TABLE,    /**< TABLE */
  TBODY,    /**< TBODY */
  TD,       /**< TD */
  TEXTAREA, /**< TEXTAREA */
  TFOOT,    /**< TFOOT */
  TH,       /**< TH */
  THEAD,    /**< THEAD */
  TITLE,    /**< TITLE */
  TR,       /**< TR */
  TT,       /**< TT */
  U,        /**< U */
  UL,       /**< UL */
  VAR,      /**< VAR */
  WBR,      /**< WBR */
  XMP,      /**< XMP */
  NEXTID,   /**< NEXTID */

  N_TIDY_TAGS       /**< Must be last */
};

/* Attribute interrogation
*/

/** Known HTML attributes
*/
public __value enum AttrId
{
  UNKNOWN,           /**< UNKNOWN= */
  ABBR,              /**< ABBR= */
  ACCEPT,            /**< ACCEPT= */
  ACCEPT_CHARSET,    /**< ACCEPT_CHARSET= */
  ACCESSKEY,         /**< ACCESSKEY= */
  ACTION,            /**< ACTION= */
  ADD_DATE,          /**< ADD_DATE= */
  ALIGN,             /**< ALIGN= */
  ALINK,             /**< ALINK= */
  ALT,               /**< ALT= */
  ARCHIVE,           /**< ARCHIVE= */
  AXIS,              /**< AXIS= */
  BACKGROUND,        /**< BACKGROUND= */
  BGCOLOR,           /**< BGCOLOR= */
  BGPROPERTIES,      /**< BGPROPERTIES= */
  BORDER,            /**< BORDER= */
  BORDERCOLOR,       /**< BORDERCOLOR= */
  BOTTOMMARGIN,      /**< BOTTOMMARGIN= */
  CELLPADDING,       /**< CELLPADDING= */
  CELLSPACING,       /**< CELLSPACING= */
  CHAR,              /**< CHAR= */
  CHAROFF,           /**< CHAROFF= */
  CHARSET,           /**< CHARSET= */
  CHECKED,           /**< CHECKED= */
  CITE,              /**< CITE= */
  CLASS,             /**< CLASS= */
  CLASSID,           /**< CLASSID= */
  CLEAR,             /**< CLEAR= */
  CODE,              /**< CODE= */
  CODEBASE,          /**< CODEBASE= */
  CODETYPE,          /**< CODETYPE= */
  COLOR,             /**< COLOR= */
  COLS,              /**< COLS= */
  COLSPAN,           /**< COLSPAN= */
  COMPACT,           /**< COMPACT= */
  CONTENT,           /**< CONTENT= */
  COORDS,            /**< COORDS= */
  DATA,              /**< DATA= */
  DATAFLD,           /**< DATAFLD= */
  DATAFORMATAS,      /**< DATAFORMATAS= */
  DATAPAGESIZE,      /**< DATAPAGESIZE= */
  DATASRC,           /**< DATASRC= */
  DATETIME,          /**< DATETIME= */
  DECLARE,           /**< DECLARE= */
  DEFER,             /**< DEFER= */
  DIR,               /**< DIR= */
  DISABLED,          /**< DISABLED= */
  ENCODING,          /**< ENCODING= */
  ENCTYPE,           /**< ENCTYPE= */
  FACE,              /**< FACE= */
  FOR,               /**< FOR= */
  FRAME,             /**< FRAME= */
  FRAMEBORDER,       /**< FRAMEBORDER= */
  FRAMESPACING,      /**< FRAMESPACING= */
  GRIDX,             /**< GRIDX= */
  GRIDY,             /**< GRIDY= */
  HEADERS,           /**< HEADERS= */
  HEIGHT,            /**< HEIGHT= */
  HREF,              /**< HREF= */
  HREFLANG,          /**< HREFLANG= */
  HSPACE,            /**< HSPACE= */
  HTTP_EQUIV,        /**< HTTP_EQUIV= */
  ID,                /**< ID= */
  ISMAP,             /**< ISMAP= */
  LABEL,             /**< LABEL= */
  LANG,              /**< LANG= */
  LANGUAGE,          /**< LANGUAGE= */
  LAST_MODIFIED,     /**< LAST_MODIFIED= */
  LAST_VISIT,        /**< LAST_VISIT= */
  LEFTMARGIN,        /**< LEFTMARGIN= */
  LINK,              /**< LINK= */
  LONGDESC,          /**< LONGDESC= */
  LOWSRC,            /**< LOWSRC= */
  MARGINHEIGHT,      /**< MARGINHEIGHT= */
  MARGINWIDTH,       /**< MARGINWIDTH= */
  MAXLENGTH,         /**< MAXLENGTH= */
  MEDIA,             /**< MEDIA= */
  METHOD,            /**< METHOD= */
  MULTIPLE,          /**< MULTIPLE= */
  NAME,              /**< NAME= */
  NOHREF,            /**< NOHREF= */
  NORESIZE,          /**< NORESIZE= */
  NOSHADE,           /**< NOSHADE= */
  NOWRAP,            /**< NOWRAP= */
  OBJECT,            /**< OBJECT= */
  OnAFTERUPDATE,     /**< OnAFTERUPDATE= */
  OnBEFOREUNLOAD,    /**< OnBEFOREUNLOAD= */
  OnBEFOREUPDATE,    /**< OnBEFOREUPDATE= */
  OnBLUR,            /**< OnBLUR= */
  OnCHANGE,          /**< OnCHANGE= */
  OnCLICK,           /**< OnCLICK= */
  OnDATAAVAILABLE,   /**< OnDATAAVAILABLE= */
  OnDATASETCHANGED,  /**< OnDATASETCHANGED= */
  OnDATASETCOMPLETE, /**< OnDATASETCOMPLETE= */
  OnDBLCLICK,        /**< OnDBLCLICK= */
  OnERRORUPDATE,     /**< OnERRORUPDATE= */
  OnFOCUS,           /**< OnFOCUS= */
  OnKEYDOWN,         /**< OnKEYDOWN= */
  OnKEYPRESS,        /**< OnKEYPRESS= */
  OnKEYUP,           /**< OnKEYUP= */
  OnLOAD,            /**< OnLOAD= */
  OnMOUSEDOWN,       /**< OnMOUSEDOWN= */
  OnMOUSEMOVE,       /**< OnMOUSEMOVE= */
  OnMOUSEOUT,        /**< OnMOUSEOUT= */
  OnMOUSEOVER,       /**< OnMOUSEOVER= */
  OnMOUSEUP,         /**< OnMOUSEUP= */
  OnRESET,           /**< OnRESET= */
  OnROWENTER,        /**< OnROWENTER= */
  OnROWEXIT,         /**< OnROWEXIT= */
  OnSELECT,          /**< OnSELECT= */
  OnSUBMIT,          /**< OnSUBMIT= */
  OnUNLOAD,          /**< OnUNLOAD= */
  PROFILE,           /**< PROFILE= */
  PROMPT,            /**< PROMPT= */
  RBSPAN,            /**< RBSPAN= */
  READONLY,          /**< READONLY= */
  REL,               /**< REL= */
  REV,               /**< REV= */
  RIGHTMARGIN,       /**< RIGHTMARGIN= */
  ROWS,              /**< ROWS= */
  ROWSPAN,           /**< ROWSPAN= */
  RULES,             /**< RULES= */
  SCHEME,            /**< SCHEME= */
  SCOPE,             /**< SCOPE= */
  SCROLLING,         /**< SCROLLING= */
  SELECTED,          /**< SELECTED= */
  SHAPE,             /**< SHAPE= */
  SHOWGRID,          /**< SHOWGRID= */
  SHOWGRIDX,         /**< SHOWGRIDX= */
  SHOWGRIDY,         /**< SHOWGRIDY= */
  SIZE,              /**< SIZE= */
  SPAN,              /**< SPAN= */
  SRC,               /**< SRC= */
  STANDBY,           /**< STANDBY= */
  START,             /**< START= */
  STYLE,             /**< STYLE= */
  SUMMARY,           /**< SUMMARY= */
  TABINDEX,          /**< TABINDEX= */
  TARGET,            /**< TARGET= */
  TEXT,              /**< TEXT= */
  TITLE,             /**< TITLE= */
  TOPMARGIN,         /**< TOPMARGIN= */
  TYPE,              /**< TYPE= */
  USEMAP,            /**< USEMAP= */
  VALIGN,            /**< VALIGN= */
  VALUE,             /**< VALUE= */
  VALUETYPE,         /**< VALUETYPE= */
  VERSION,           /**< VERSION= */
  VLINK,             /**< VLINK= */
  VSPACE,            /**< VSPACE= */
  WIDTH,             /**< WIDTH= */
  WRAP,              /**< WRAP= */
  XML_LANG,          /**< XML_LANG= */
  XML_SPACE,         /**< XML_SPACE= */
  XMLNS,             /**< XMLNS= */

  EVENT,             /**< EVENT= */
  METHODS,           /**< METHODS= */
  N,                 /**< N= */
  SDAFORM,           /**< SDAFORM= */
  SDAPREF,           /**< SDAPREF= */
  SDASUFF,           /**< SDASUFF= */
  URN,               /**< URN= */

  N_TIDY_ATTRIBS              /**< Must be last */
};

#endif // 0

public __gc class CharEnc {
public:
	static const String* Ascii		= S"ascii";
	static const String* Latin0		= S"latin0";
	static const String* Latin1		= S"latin1";
	static const String* Raw		= S"raw";
	static const String* Utf8		= S"utf8";
	static const String* Iso2022	= S"iso2022";
	static const String* Mac		= S"mac";
	static const String* Win1252	= S"win1252";
	static const String* Ibm858		= S"ibm858";

#if SUPPORT_UTF16_ENCODINGS
	static const String* Utf16LE	= S"utf16le";
	static const String* Utf16BE	= S"utf16be";
	static const String* Utf16		= S"utf16";
#endif

#if SUPPORT_ASIAN_ENCODINGS
	static const String* Big5		= S"big5";
	static const String* ShiftJis	= S"shiftjis";
#endif
};

/* character encodings
*/
public __value enum CharEncId {
	Raw,
	Ascii,
	Latin0,
	Latin1,
	Utf8,
	Iso2022,
	Mac,
	Win1252,
	Ibm858,

#if SUPPORT_UTF16_ENCODINGS
	Utf16LE,
	Utf16BE,
	Utf16,
#endif

#if SUPPORT_ASIAN_ENCODINGS
	Big5,
	ShiftJis,
#endif
};